
.. image:: https://readthedocs.org/projects/galaxy-lib/badge/?version=latest
   :target: http://galaxy-lib.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://badge.fury.io/py/galaxy-lib.svg
   :target: https://pypi.python.org/pypi/galaxy-lib/

.. image:: https://travis-ci.org/galaxyproject/galaxy-lib.png?branch=master
   :target: https://travis-ci.org/galaxyproject/galaxy-lib

Overview
--------

A small subset of the Galaxy_ project for reuse outside the core. This subset has minimal dependencies and is Python 3 compatible.

* Free software: Academic Free License version 3.0
* Documentation: https://galaxy-lib.readthedocs.org.
* Code: https://github.com/galaxyproject/galaxy-lib


.. _Galaxy: http://galaxyproject.org/
.. _GitHub: https://github.com/
.. _Docker: https://www.docker.com/
.. _Homebrew: http://brew.sh/
.. _linuxbrew: https://github.com/Homebrew/linuxbrew
.. _Vagrant: https://www.vagrantup.com/
.. _Travis CI: http://travis-ci.org/
.. _`tools-devteam`: https://github.com/galaxyproject/tools-devteam
.. _`tools-iuc`: https://github.com/galaxyproject/tools-iuc
.. _Publishing to the Tool Shed: http://planemo.readthedocs.org/en/latest/publishing.html
.. _Common Workfow Language: http://common-workflow-language.github.io
